@@ -3,9 +3,9 @@
 #------------------------------------------------------------------------------#
 
 #  zzz.R
-#  R Interface to C API of IBM ILOG CPLEX Version 12.1, 12.2, 12.3, 12.4.
+#  R Interface to C API of IBM ILOG CPLEX Version 12.1, 12.2, 12.3, 12.4, 12.5.
 #
-#  Copyright (C) 2011-2012 Gabriel Gelius-Dietrich, Dpt. for Bioinformatics,
+#  Copyright (C) 2011-2013 Gabriel Gelius-Dietrich, Dpt. for Bioinformatics,
 #  Institute for Informatics, Heinrich-Heine-University, Duesseldorf, Germany.
 #  All right reserved.
 #  Email: geliudie@uni-duesseldorf.de
@@ -28,6 +28,12 @@
 
 .packageName <- "cplexAPI"
 
-.onLoad <- function(lib, pkg) {
+.onLoad <- function(libname, pkgname) {
     .Call("initCPLEX", PACKAGE = "cplexAPI")
 }
+
+#.onAttach <- function(libname, pkgname) {
+#    tmp <- openEnvCPLEX()
+#    packageStartupMessage("using IBM ILOG CPLEX version ", getVersionCPLEX(tmp))
+#    closeEnvCPLEX(tmp)
+#}
